#ifndef __SPW_H
#define __SPW_H

#include <owl\applicat.h>
#include <owl\owlpch.h>
#include <owl\edit.h>
#include <owl\combobox.h>
#include <owl\floatfra.h>
#include <owl\radiobut.h>
#include <dir.h>
#include <ddeml.h>

#include "confdlg.h"
#include "olssmodl.h"

//
// A Combo box is actually made up of three windows, an edit
// window, a list box window, and a parent window.  If we need to trap
// an event on the edit or list box window, normal OWL event handlers
// won't work.  These event handlers would trap events to the parent
// window.
//
// TComboEdit is hard wired to the control ID that MS uses for the edit
// window. This allows us to trap events, like CR.
//

const int COMBO_LIST_ID = 0x3e8;  // Window ID for list box component
const int COMBO_EDIT_ID = 0x3e9;  // Window ID for edit field component

const int EDITWIDTH  = 300;  // Width of the combo box
const int CMDBUFSIZE = 256;  // Max command size
const int COMBO_ID   = 1;


#ifndef	WM_SETHOTKEY
#define WM_SETHOTKEY 0x0032
#define WM_GETHOTKEY 0x0033
#endif

// defines for upper byte of hot key descriptor
#define SHIFT 0x0100
#define CTRL  0x0200
#define ALT   0x0400

class TComboEdit
:
	public TEdit
{
public:
	TComboEdit(TComboBox* parent, UINT textLen)
	:
		TEdit(parent, COMBO_EDIT_ID, textLen)
		{
			Combo = parent;
		}

private:
	// This is where we'll look for c/r and special keys
	void EvChar(UINT key, UINT repeatCount, UINT flags);

	void ExecuteCmd(char *cmd);
	void copyToClipboard(char *str);

	// We could also get Parent from TWindow and downcast it
	TComboBox* Combo;

	char EditBuf[CMDBUFSIZE];
	char CmdBuf[CMDBUFSIZE];

	DECLARE_RESPONSE_TABLE(TComboEdit);
};

class TLineEdit
:
	public TComboBox
{
public:
	TLineEdit(TWindow* p,int w, int h);
	TComboEdit* Ed;

   void	SetString(const char*	szString);
};

class TMakePassFrame
:
	public TFloatingFrame
{
public:
	TMakePassFrame(TWindow* client, char* title, WORD captionHeight, bool Topmost, WORD hotkey);
	~TMakePassFrame();
   void 		copyDataFromClipboard();

#ifdef  __USEDDE
	virtual 	bool MatchTopicAndService(HSZ, HSZ);
	virtual 	bool MatchTopicAndItem(HSZ, HSZ);
	virtual	HDDEDATA WildConnect(HSZ, HSZ, WORD);
	virtual 	HDDEDATA DataRequested(WORD);
	virtual 	void UpdateData();

	HCONV   	HConv;
#endif

static	bool		bquiet;

protected:
	void 				EvEnterIdle(UINT source, HWND hWndDlg);
	void 				EvSysCommand(uint cmdType, TPoint& p);

private:

	WORD			wHotkey;
	bool			F1Pressed;

	void  		SetupWindow();
	TLineEdit* 	Cmd;

	void			CmConfig();
	void			CmAbout();
	void			CmPasswordSetup();
	void        CmUpPassword();
	void        CmDownPassword();
	void			CmHelp();

#ifdef  __USEDDE

	HSZ     Service;
	HSZ     Topic;
	HSZ     Item;
	DWORD   InstId();
#endif

	DECLARE_RESPONSE_TABLE(TMakePassFrame);
};

//------------------------------------------------------------------------

class TWinPass
:
	public TApplication
{
public:

	TWinPass();
	virtual ~TWinPass();

	WORD	captionHeight;

	TConfigData config;

	DWORD   	InstId;
#ifdef  __USEDDE
	static  	TMakePassFrame* This;
#endif
#ifndef	__WIN32__
	static  	char ProfileName[MAXPATH];
#endif
	static  	char HelpName[MAXPATH];

	static  	const char *ApplicationName;

#ifdef	__WIN32__
	static	const char*		szREGBase;
   static	const char*		szREGMajorVersion;
	static	const char*		szREGMinorVersion;
	static	const char*		szREGBuild;
	static	const char*		szREGInstallationDate;
	static	const char *	szREGHelpFilename;

	static	const  char*	szREGDebugSection;
	static   const  char* 	szREGDebug;

	static   const	char*		szREGHotkeySection;
	static   const	char*		szREGHotkeyActivation;
	static	const	char*		szREGHotkeyValue;
	static   const	char*		szREGClipChallenge;

	static   const	char*		szREGTopmostWindow;
	static   const	char*		szREGCaptionHeight;
	static   const	char*		szREGCopyToClipboard;
	static	const char*		szREGIconizeAfterUse;
#else
   static	const  char*	INIDebugSection;
	static   const  char*	INIDebug;

	static   const	char*		INIHotkeySection;
	static   const	char*		INIHotkeyActivation;
	static	const	char*		INIHotkeyValue;
	static   const	char*		INIClipChallenge;

	static   const	char*		INITopmostWindow;
	static   const	char*		INICaptionHeight;
	static   const	char*		INICopyToClipboard;
	static	const char*		INIIconizeAfterUse;
#endif
protected:

	dword		dwMajorVersion;
   dword		dwMinorVersion;
   dword    dwBuild;
   dword		dwInstallationDate;

	WORD		wHotkey;

	void	WriteINIFile();
	void	ReadINIFile();
	void	MakeHotkey();

	virtual	void 	InitMainWindow();

	virtual	void 	InitInstance();
	virtual	int 	TermInstance(int status);

#ifdef  __USEDDE

	static HDDEDATA FAR PASCAL _export CallBack(WORD, WORD, HCONV, HSZ, HSZ,
																HDDEDATA, DWORD, DWORD);

	TProcInstance CallBackProc;

#endif

};

#endif
